<?php

namespace Drupal\webform_email_confirmation_link\Controller;

use Drupal\Component\Datetime\TimeInterface;
use Drupal\Core\Controller\ControllerBase;
use Drupal\Core\Entity\EntityTypeManagerInterface;
use Symfony\Component\DependencyInjection\ContainerInterface;
use Symfony\Component\HttpFoundation\RedirectResponse;
use Drupal\Core\Url;

/**
 * Controller routines for admin block routes.
 */
class WebformEmailConfirmationController extends ControllerBase {

  /**
   * The entity type manager.
   *
   * @var \Drupal\Core\Entity\EntityTypeManagerInterface
   */
  protected $entityTypeManager;

  /**
   * The time service.
   *
   * @var \Drupal\Component\Datetime\TimeInterface
   */
  protected $time;

  /**
   * Constructs a new WebformEmailConfirmationController instance.
   *
   * @param \Drupal\Core\Entity\EntityTypeManagerInterface $entity_type_manager
   *   The entity type manager.
   * @param \Drupal\Component\Datetime\TimeInterface $time
   *   The time service.
   */
  public function __construct(EntityTypeManagerInterface $entity_type_manager, TimeInterface $time) {
    $this->entityTypeManager = $entity_type_manager;
    $this->time = $time;
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container) {
    return new static(
      $container->get('entity_type.manager'),
      $container->get('datetime.time')
    );
  }

  /**
   * The webform confirmation route.
   *
   * @param string $uuid
   *   The webform submission UUID.
   *
   * @return \Symfony\Component\HttpFoundation\RedirectResponse
   *   The redirect to homepage.
   */
  public function confirmation(string $uuid) {
    $webform_submission = $this->entityTypeManager
      ->getStorage('webform_submission')
      ->loadByProperties([
        'uuid' => $uuid,
      ]);

    if (empty($webform_submission)) {
      return new RedirectResponse(Url::fromRoute('<front>')->toString());
    }

    /** @var \Drupal\webform\Entity\WebformSubmission $webform_submission */
    $webform_submission = reset($webform_submission);
    $webform_submission->set('in_draft', FALSE);
    $webform_submission->set('completed', TRUE);

    $request_time = $this->time->getRequestTime();
    $webform_submission->setCompletedTime($request_time);
    $webform_submission->setChangedTime($request_time);
    $webform_submission->save();

    $this->messenger()->addMessage($this->t('Your submission has been confirmed'));

    return new RedirectResponse(Url::fromRoute('<front>')->toString());
  }

}
